@@ -65,6 +65,7 @@ from cognite_toolkit._cdf_tk.exceptions import (
     ToolkitMissingModuleError,
     ToolkitYAMLFormatError,
 )
+from cognite_toolkit._cdf_tk.feature_flags import Flags
 from cognite_toolkit._cdf_tk.hints import Hint, ModuleDefinition, verify_module_directory
 from cognite_toolkit._cdf_tk.tk_warnings import (
     DuplicatedItemWarning,
@@ -358,6 +359,16 @@ class BuildCommand(ToolkitCommand):
         for resource_name, resource_files in module.source_paths_by_resource_folder.items():
             source_files = self._replace_variables(resource_files, module_variables, resource_name, module.dir, verbose)
 
+            if resource_name == "data_models":
+                resource_name = "data_modeling"
+                if Flags.v07:
+                    self.warn(
+                        MediumSeverityWarning(
+                            "The resource folder 'data_models' is deprecated and will be removed in v1.0. "
+                            "Please rename the folder to 'data_modeling'."
+                        )
+                    )
+
             builder = self._get_builder(build_dir, resource_name)
 
             built_resources = BuiltResourceList[Hashable]()
