@@ -19,7 +19,7 @@ from cognite_toolkit._cdf_tk.commands.collect import CollectCommand
 from cognite_toolkit._cdf_tk.commands.modules import ModulesCommand
 from cognite_toolkit._cdf_tk.commands.repo import RepoCommand
 from cognite_toolkit._cdf_tk.exceptions import ToolkitError
-from cognite_toolkit._cdf_tk.feature_flags import Flags
+from cognite_toolkit._cdf_tk.feature_flags import FeatureFlag, Flags
 
 
 class InitItemStatus(Enum):
@@ -32,8 +32,6 @@ class InitItemStatus(Enum):
 
 @dataclass
 class InitChecklistItem:
-    """Represents an item in the init checklist"""
-
     name: str
     description: str
     function: Callable[[], None]
@@ -41,7 +39,6 @@ class InitChecklistItem:
     mandatory: bool = False
 
     def get_status_display(self) -> str:
-        """Get a display string for the status"""
         if self.status == InitItemStatus.SUCCESSFUL:
             return "✓"
         elif self.status == InitItemStatus.FAILED:
@@ -50,12 +47,17 @@ class InitChecklistItem:
             return "○"
 
     def get_choice_title(self) -> str:
-        """Get the title for the questionary choice"""
         status_icon = self.get_status_display()
         return f"{status_icon} {self.description} (required)" if self.mandatory else f"{status_icon} {self.description}"
 
 
 class InitCommand(ToolkitCommand):
+    organization_dir: Path | None
+
+    def __init__(self, print_warning: bool = True, skip_tracking: bool = False, silent: bool = False) -> None:
+        super().__init__(print_warning, skip_tracking, silent)
+        self.organization_dir = None
+
     def execute(self, dry_run: bool = False, emulate_dot_seven: bool = False) -> None:
         if not Flags.v07.is_enabled() and not emulate_dot_seven:
             print("This command is deprecated. Use 'cdf modules init' instead.")
@@ -140,7 +142,6 @@ class InitCommand(ToolkitCommand):
             if selected == "__exit__":
                 if all_mandatory_complete:
                     print("Setup complete!")
-                    print("You can now start using the Cognite Toolkit.")
                     break
                 else:
                     incomplete_mandatory = [
@@ -168,7 +169,6 @@ class InitCommand(ToolkitCommand):
                 if not confirm:
                     continue
 
-            # Run the function
             try:
                 selected_item.function()
                 selected_item.status = InitItemStatus.SUCCESSFUL
@@ -188,12 +188,14 @@ class InitCommand(ToolkitCommand):
                 print(f"Unexpected error occurred. Full traceback:\n{traceback.format_exc()}")
 
     def _init_toml(self, dry_run: bool = False) -> None:
-        organization_dir = ModulesCommand._prompt_organization_dir()
+        if self.organization_dir is None:
+            self.organization_dir = ModulesCommand._prompt_organization_dir()
         if dry_run:
             print("Would initialize cdf.toml configuration file")
             return
-        CDFToml.write(organization_dir, "dev")
-        print(f"cdf.toml configuration file initialized in {organization_dir}")
+        CDFToml.write(self.organization_dir, "dev")
+        FeatureFlag.flush()
+        print(f"cdf.toml configuration file initialized in {self.organization_dir}")
 
     def _init_auth(self, dry_run: bool = False) -> None:
         auth_command = AuthCommand()
@@ -201,12 +203,14 @@ class InitCommand(ToolkitCommand):
 
     def _init_modules(self, dry_run: bool = False) -> None:
         with ModulesCommand() as modules_command:
+            if self.organization_dir is None:
+                self.organization_dir = ModulesCommand._prompt_organization_dir()
             if dry_run:
                 organization_dir = Path(tempfile.mkdtemp(prefix="init_modules_", suffix=".tmp", dir=Path.cwd()))
                 modules_command.run(lambda: modules_command.init(organization_dir=organization_dir))
                 shutil.rmtree(organization_dir)
             else:
-                modules_command.run(lambda: modules_command.init())
+                modules_command.run(lambda: modules_command.init(organization_dir=self.organization_dir))
 
     def _init_repo(self, dry_run: bool = False) -> None:
         repo_command = RepoCommand()
@@ -216,7 +220,7 @@ class InitCommand(ToolkitCommand):
         """Opt in to collect usage statistics"""
 
         opt_in = questionary.confirm(
-            "Do you want to opt in to collect usage statistics?",
+            "Do you want to opt in to collect usage statistics? This will help us improve the Toolkit.",
             default=True,
         ).ask()
         if dry_run:
