@@ -120,7 +120,7 @@ from .auth import GroupAllScopedCRUD
 @final
 class SpaceCRUD(ResourceContainerCRUD[str, SpaceApply, Space, SpaceApplyList, SpaceList]):
     item_name = "nodes and edges"
-    folder_name = "data_models"
+    folder_name = "data_modeling"
     filename_pattern = r"^.*space$"
     resource_cls = Space
     resource_write_cls = SpaceApply
@@ -252,7 +252,7 @@ class SpaceCRUD(ResourceContainerCRUD[str, SpaceApply, Space, SpaceApplyList, Sp
 
 class ContainerCRUD(ResourceContainerCRUD[ContainerId, ContainerApply, Container, ContainerApplyList, ContainerList]):
     item_name = "nodes and edges"
-    folder_name = "data_models"
+    folder_name = "data_modeling"
     filename_pattern = r"^.*container$"
     resource_cls = Container
     resource_write_cls = ContainerApply
@@ -328,6 +328,7 @@ class ContainerCRUD(ResourceContainerCRUD[ContainerId, ContainerApply, Container
 
     def dump_resource(self, resource: Container, local: dict[str, Any] | None = None) -> dict[str, Any]:
         dumped = resource.as_write().dump()
+        has_local = local is not None
         local = local or {}
         for key in ["constraints", "indexes"]:
             if not dumped.get(key) and key not in local:
@@ -339,15 +340,16 @@ class ContainerCRUD(ResourceContainerCRUD[ContainerId, ContainerApply, Container
                 continue
             local_prop = local_prop_by_id[prop_id]
             for key, default in [("immutable", False), ("autoIncrement", False), ("nullable", True)]:
-                if cdf_prop.get(key) is default and key not in local_prop:
+                if has_local and cdf_prop.get(key) is default and key not in local_prop:
                     cdf_prop.pop(key, None)
             cdf_type = cdf_prop.get("type", {})
             local_type = local_prop.get("type", {})
             for key, type_default in [("list", False), ("collation", "ucs_basic")]:
-                if cdf_type.get(key) == type_default and key not in local_type:
+                if has_local and cdf_type.get(key) == type_default and key not in local_type:
                     cdf_type.pop(key, None)
-        if "usedFor" not in local:
-            dumped.pop("usedFor", None)
+            if has_local and "usedFor" not in local and dumped.get("usedFor") == "node":
+                # Only drop if set to default by server.
+                dumped.pop("usedFor", None)
         return dumped
 
     def create(self, items: Sequence[ContainerApply]) -> ContainerList:
@@ -514,7 +516,7 @@ class ContainerCRUD(ResourceContainerCRUD[ContainerId, ContainerApply, Container
 
 
 class ViewCRUD(ResourceCRUD[ViewId, ViewApply, View, ViewApplyList, ViewList]):
-    folder_name = "data_models"
+    folder_name = "data_modeling"
     filename_pattern = r"^.*view$"
     resource_cls = View
     resource_write_cls = ViewApply
@@ -855,7 +857,7 @@ class ViewCRUD(ResourceCRUD[ViewId, ViewApply, View, ViewApplyList, ViewList]):
 
 @final
 class DataModelCRUD(ResourceCRUD[DataModelId, DataModelApply, DataModel, DataModelApplyList, DataModelList]):
-    folder_name = "data_models"
+    folder_name = "data_modeling"
     filename_pattern = r"^.*datamodel$"
     resource_cls = DataModel
     resource_write_cls = DataModelApply
@@ -989,7 +991,7 @@ class DataModelCRUD(ResourceCRUD[DataModelId, DataModelApply, DataModel, DataMod
 @final
 class NodeCRUD(ResourceContainerCRUD[NodeId, NodeApply, Node, NodeApplyList, NodeList]):
     item_name = "nodes"
-    folder_name = "data_models"
+    folder_name = "data_modeling"
     filename_pattern = r"^.*node$"
     resource_cls = Node
     resource_write_cls = NodeApply
@@ -1148,7 +1150,7 @@ class GraphQLCRUD(
         DataModelId, GraphQLDataModelWrite, GraphQLDataModel, GraphQLDataModelWriteList, GraphQLDataModelList
     ]
 ):
-    folder_name = "data_models"
+    folder_name = "data_modeling"
     filename_pattern = r"^.*GraphQLSchema"
     resource_cls = GraphQLDataModel
     resource_write_cls = GraphQLDataModelWrite
@@ -1348,7 +1350,7 @@ class GraphQLCRUD(
 @final
 class EdgeCRUD(ResourceContainerCRUD[EdgeId, EdgeApply, Edge, EdgeApplyList, EdgeList]):
     item_name = "edges"
-    folder_name = "data_models"
+    folder_name = "data_modeling"
     filename_pattern = r"^.*edge"
     resource_cls = Edge
     resource_write_cls = EdgeApply
