@@ -13,7 +13,6 @@
 # limitations under the License.
 
 
-import re
 from collections.abc import Hashable, Iterable, Sequence
 from pathlib import Path
 from typing import Any, final
@@ -295,10 +294,6 @@ class ExtractionPipelineConfigCRUD(
     def load_resource(self, resource: dict[str, Any], is_dry_run: bool = False) -> ExtractionPipelineConfigWrite:
         config_raw = resource.get("config")
         if isinstance(config_raw, str):
-            # There might be keyvaults secrets in the config that would lead to parsing errors. The syntax
-            # for this is `connection-string: !keyvault secret`. This is not valid YAML, so we need to
-            # replace it with `connection-string: keyvault secret` to make it valid.
-            config_raw = re.sub(r":\s+!(\w+)", r": \1", config_raw)
             self._validate_config(config_raw, resource)
         return ExtractionPipelineConfigWrite._load(resource)
 
